==> moyoung_ble_plugin-1.0.3.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/HeartRateHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.bean.CRPHeartRateInfo;
import com.crrepa.ble.conn.bean.CRPHistoryHeartRateInfo;
import com.crrepa.ble.conn.bean.CRPMovementHeartRateInfo;
import com.crrepa.ble.conn.listener.CRPHeartRateChangeListener;
import com.crrepa.ble.conn.type.CRPHistoryDynamicRateType;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.HeartRateBean;
import com.moyoung.moyoung_ble_plugin.model.MeasureCompleteBean;

import java.util.List;
import android.util.Log;

import io.flutter.plugin.common.MethodCall;

public class HeartRateHandler extends BaseConnectionEventChannelHandler {
    private final static String TAG = HeartRateHandler.class.getSimpleName();

    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setHeartRateChangeListener(new CRPHeartRateChangeListener() {
            @Override
            public void onMeasuring(int measuring) {
                if (eventSink == null) {
                    return;
                }
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.MEASURING);
                heartRateBean.setMeasuring(measuring);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void onOnceMeasureComplete(int onceMeasureComplete) {
                if (eventSink == null) {
                    return;
                }
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.ONCEMEASURECOMPLETE);
                heartRateBean.setOnceMeasureComplete(onceMeasureComplete);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                Log.d(TAG, "onOnceMeasureComplete: "+heartRateStr);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void onHistoryHeartRate(List<CRPHistoryHeartRateInfo> historyHRList) {
                if (eventSink == null) {
                    return;
                }
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.HEARTRATE);
                heartRateBean.setHistoryHRList(historyHRList);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void onMeasureComplete(CRPHistoryDynamicRateType historyDynamicRateType,
                                          CRPHeartRateInfo heartRateInfo) {
                if (eventSink == null) {
                    return;
                }
                MeasureCompleteBean measureComplete = new MeasureCompleteBean(
                        historyDynamicRateType,heartRateInfo);
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.MEASURECOMPLETE);
                heartRateBean.setMeasureComplete(measureComplete);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void on24HourMeasureResult(CRPHeartRateInfo crpHeartRateInfo) {
                if (eventSink == null) {
                    return;
                }
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.HOURMEASURERESULTOF24);
                heartRateBean.setHour24MeasureResult(crpHeartRateInfo);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void onMovementMeasureResult(List<CRPMovementHeartRateInfo> movementMeasureList) {
                if (eventSink == null) {
                    return;
                }
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.MOVEMENTMEASURERESULT);
                heartRateBean.setTrainingList(movementMeasureList);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }
        });
    }

}

==> moyoung_ble_plugin-1.0.32.tar.gz: android/src/main/java/com/moyoung/moyoung_ble_plugin/event/HeartRateHandler.java <==
package com.moyoung.moyoung_ble_plugin.event;

import com.crrepa.ble.conn.CRPBleConnection;
import com.crrepa.ble.conn.bean.CRPHeartRateInfo;
import com.crrepa.ble.conn.bean.CRPHistoryHeartRateInfo;
import com.crrepa.ble.conn.bean.CRPMovementHeartRateInfo;
import com.crrepa.ble.conn.listener.CRPHeartRateChangeListener;
import com.crrepa.ble.conn.type.CRPHistoryDay;
import com.crrepa.ble.conn.type.CRPHistoryDynamicRateType;
import com.moyoung.moyoung_ble_plugin.base.BaseConnectionEventChannelHandler;
import com.moyoung.moyoung_ble_plugin.common.GsonUtils;
import com.moyoung.moyoung_ble_plugin.model.HeartRateBean;
import com.moyoung.moyoung_ble_plugin.model.MeasureCompleteBean;

import java.util.List;

import io.flutter.plugin.common.MethodCall;

public class HeartRateHandler extends BaseConnectionEventChannelHandler {

    @Override
    public void setConnListener(CRPBleConnection connection, MethodCall call) {
        connection.setHeartRateChangeListener(new CRPHeartRateChangeListener() {
            @Override
            public void onMeasuring(int measuring) {
                if (eventSink == null) {
                    return;
                }
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.MEASURING);
                heartRateBean.setMeasuring(measuring);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void onOnceMeasureComplete(int onceMeasureComplete) {
                if (eventSink == null) {
                    return;
                }
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.ONCEMEASURECOMPLETE);
                heartRateBean.setOnceMeasureComplete(onceMeasureComplete);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void onHistoryHeartRate(List<CRPHistoryHeartRateInfo> historyHRList) {
                if (eventSink == null) {
                    return;
                }
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.HEARTRATE);
                heartRateBean.setHistoryHRList(historyHRList);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void onMeasureComplete(CRPHistoryDynamicRateType historyDynamicRateType,
                                          CRPHeartRateInfo heartRateInfo) {
                if (eventSink == null) {
                    return;
                }
                MeasureCompleteBean measureComplete = new MeasureCompleteBean(
                        historyDynamicRateType,heartRateInfo);
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.MEASURECOMPLETE);
                heartRateBean.setMeasureComplete(measureComplete);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void on24HourMeasureResult(CRPHeartRateInfo heartRateInfo) {
                if (eventSink == null) {
                    return;
                }
                long startTime = heartRateInfo.getStartTime() / 1000;
                List<Integer> heartRateList = heartRateInfo.getHeartRateList();
                int timeInterval = heartRateInfo.getTimeInterval();
                boolean isAllDay = heartRateInfo.isAllDay();
                CRPHistoryDay historyDay = heartRateInfo.getHistoryDay();
                CRPHeartRateInfo crpHeartRateInfo = new CRPHeartRateInfo(startTime, heartRateList, timeInterval, isAllDay, historyDay);
                HeartRateBean heartRateBean = new HeartRateBean(HeartRateBean.HOURMEASURERESULTOF24);
                heartRateBean.setHour24MeasureResult(crpHeartRateInfo);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }

            @Override
            public void onMovementMeasureResult(List<CRPMovementHeartRateInfo> movementMeasureList) {
                if (eventSink == null) {
                    return;
                }
                HeartRateBean heartRateBean =new HeartRateBean(HeartRateBean.MOVEMENTMEASURERESULT);
                heartRateBean.setTrainingList(movementMeasureList);
                String heartRateStr=GsonUtils.get().toJson(heartRateBean, HeartRateBean.class);
                activity.runOnUiThread(() -> eventSink.success(heartRateStr));
            }
        });
    }

}
